loadPdfFromFile method

Future<String?> loadPdfFromFile(
  1. String path,
  2. String documentID, [
  3. String? password
])
inherited

Initializes the PDF renderer instance in respective platform by loading the PDF from the specified file path.

If success, returns page count else returns error message from respective platform

Implementation

Future<String?> loadPdfFromFile(
  String path,
  String documentID, [
  String? password,
]) {
  throw UnimplementedError('loadPdfFromFile() has not been implemented.');
}